summaryrefslogtreecommitdiffstats
path: root/src/classes
diff options
context:
space:
mode:
Diffstat (limited to 'src/classes')
-rw-r--r--src/classes/org/jdesktop/j3d/examples/configured_universe/ConfigObjLoad.java9
-rw-r--r--src/classes/org/jdesktop/j3d/examples/fps_counter/FPSCounterDemo.java3
-rw-r--r--src/classes/org/jdesktop/j3d/examples/geometry_compression/ObjectFileCompressor.java40
-rw-r--r--src/classes/org/jdesktop/j3d/examples/geometry_compression/README.txt2
-rw-r--r--src/classes/org/jdesktop/j3d/examples/geometry_compression/cgview.java49
-rw-r--r--src/classes/org/jdesktop/j3d/examples/geometry_compression/obj2cg.java5
-rw-r--r--src/classes/org/jdesktop/j3d/examples/texture/TextureImage.java11
-rw-r--r--src/classes/org/jdesktop/j3d/examples/texture/TextureImageNPOT.java222
8 files changed, 276 insertions, 65 deletions
diff --git a/src/classes/org/jdesktop/j3d/examples/configured_universe/ConfigObjLoad.java b/src/classes/org/jdesktop/j3d/examples/configured_universe/ConfigObjLoad.java
index 16d1060..8cd44bb 100644
--- a/src/classes/org/jdesktop/j3d/examples/configured_universe/ConfigObjLoad.java
+++ b/src/classes/org/jdesktop/j3d/examples/configured_universe/ConfigObjLoad.java
@@ -189,9 +189,12 @@ public class ConfigObjLoad {
// Get the config file URL from the j3d.configURL property or use the
// default config file "j3d1x1-window" in the current directory.
- //URL configURL = ConfiguredUniverse.getConfigURL("file:j3d1x1-window");
- URL configURL = Resources.getResource("configured_universe/j3d1x1-windows.cfg");
- // Create a simple scene and attach it to the virtual universe
+ URL configURL = ConfiguredUniverse.getConfigURL(null);
+ if(configURL == null) {
+ configURL = Resources.getResource("configured_universe/j3d1x1-window.cfg");
+ }
+
+ // Create a simple scene and attach it to the virtual universe
BranchGroup scene = createSceneGraph();
u = new ConfiguredUniverse(configURL);
diff --git a/src/classes/org/jdesktop/j3d/examples/fps_counter/FPSCounterDemo.java b/src/classes/org/jdesktop/j3d/examples/fps_counter/FPSCounterDemo.java
index d7f8ee9..88ca026 100644
--- a/src/classes/org/jdesktop/j3d/examples/fps_counter/FPSCounterDemo.java
+++ b/src/classes/org/jdesktop/j3d/examples/fps_counter/FPSCounterDemo.java
@@ -118,9 +118,6 @@ public class FPSCounterDemo extends javax.swing.JFrame {
// objects in the scene can be viewed.
univ.getViewingPlatform().setNominalViewingTransform();
- // Ensure at least 5 msec per frame (i.e., < 200Hz)
- univ.getViewer().getView().setMinimumFrameCycleTime(5);
-
return c;
}
diff --git a/src/classes/org/jdesktop/j3d/examples/geometry_compression/README.txt b/src/classes/org/jdesktop/j3d/examples/geometry_compression/README.txt
index 1cab35b..345766b 100644
--- a/src/classes/org/jdesktop/j3d/examples/geometry_compression/README.txt
+++ b/src/classes/org/jdesktop/j3d/examples/geometry_compression/README.txt
@@ -1,5 +1,5 @@
This directory contains example code for using compressed geometry in
-Java 3D through the com.sun.j3d.utils.compression package.
+Java 3D through the com.sun.j3d.utils.geometry.compression package.
Applications:
diff --git a/src/classes/org/jdesktop/j3d/examples/geometry_compression/cgview.java b/src/classes/org/jdesktop/j3d/examples/geometry_compression/cgview.java
index 2efc221..23e027a 100644
--- a/src/classes/org/jdesktop/j3d/examples/geometry_compression/cgview.java
+++ b/src/classes/org/jdesktop/j3d/examples/geometry_compression/cgview.java
@@ -44,22 +44,21 @@
package org.jdesktop.j3d.examples.geometry_compression;
-import com.sun.j3d.utils.compression.* ;
-import com.sun.j3d.utils.behaviors.vp.* ;
-import com.sun.j3d.utils.applet.MainFrame ;
-import com.sun.j3d.utils.universe.* ;
-import javax.media.j3d.* ;
-import javax.vecmath.* ;
-import java.applet.Applet ;
-import java.awt.BorderLayout ;
-import java.awt.event.* ;
-import java.io.* ;
+import com.sun.j3d.utils.applet.MainFrame;
+import com.sun.j3d.utils.behaviors.vp.OrbitBehavior;
+import com.sun.j3d.utils.geometry.compression.*;
+import com.sun.j3d.utils.universe.*;
+import java.applet.Applet;
+import java.awt.BorderLayout;
+import java.io.IOException;
+import javax.media.j3d.*;
+import javax.vecmath.*;
public class cgview extends Applet {
private SimpleUniverse u = null;
- public BranchGroup createSceneGraph(CompressedGeometry cg) {
+ public BranchGroup createSceneGraph(CompressedGeometryData cg) {
// Create the root of the branch graph
BranchGroup objRoot = new BranchGroup() ;
@@ -81,27 +80,15 @@ public class cgview extends Applet {
objScale.addChild(objTrans) ;
// Add compressed geometry to the scene graph.
- CompressedGeometryHeader hdr = new CompressedGeometryHeader() ;
+ CompressedGeometryData.Header hdr = new CompressedGeometryData.Header() ;
cg.getCompressedGeometryHeader(hdr) ;
- // There isn't really enough information in the compressed geometry
- // header to unamiguously determine the proper rendering attributes.
- // The bufferDataPresent field specifies whether or not normals are
- // bundled with vertices, but the compressed buffer can still contain
- // normals that should be lit. Assume that any surface geometry
- // should be lit and that lines and points should not unless the
- // header contains the NORMAL_IN_BUFFER bit.
- Material m = new Material() ;
- if ((hdr.bufferType == hdr.TRIANGLE_BUFFER) ||
- ((hdr.bufferDataPresent & hdr.NORMAL_IN_BUFFER) == 1))
- m.setLightingEnable(true) ;
- else
- m.setLightingEnable(false) ;
-
- Appearance a = new Appearance() ;
- a.setMaterial(m) ;
-
- objTrans.addChild(new Shape3D(cg, a)) ;
+ Shape3D[] shapes = cg.decompress();
+ if (shapes != null) {
+ for (int i = 0; i < shapes.length; i++) {
+ objTrans.addChild(shapes[i]);
+ }
+ }
// Create mouse behavior scheduling bounds.
BoundingSphere bounds =
@@ -158,7 +145,7 @@ public class cgview extends Applet {
usage() ;
// Read the compressed geometry.
- CompressedGeometry cg = null ;
+ CompressedGeometryData cg = null ;
try {
CompressedGeometryFile cgf ;
cgf = new CompressedGeometryFile(filename, false) ;
diff --git a/src/classes/org/jdesktop/j3d/examples/geometry_compression/obj2cg.java b/src/classes/org/jdesktop/j3d/examples/geometry_compression/obj2cg.java
index e863dbc..4d3fa66 100644
--- a/src/classes/org/jdesktop/j3d/examples/geometry_compression/obj2cg.java
+++ b/src/classes/org/jdesktop/j3d/examples/geometry_compression/obj2cg.java
@@ -44,9 +44,8 @@
package org.jdesktop.j3d.examples.geometry_compression;
-import com.sun.j3d.utils.compression.* ;
-import javax.media.j3d.* ;
-import java.io.* ;
+import com.sun.j3d.utils.geometry.compression.*;
+import java.io.IOException;
class obj2cg {
diff --git a/src/classes/org/jdesktop/j3d/examples/texture/TextureImage.java b/src/classes/org/jdesktop/j3d/examples/texture/TextureImage.java
index 5ac421e..59cec91 100644
--- a/src/classes/org/jdesktop/j3d/examples/texture/TextureImage.java
+++ b/src/classes/org/jdesktop/j3d/examples/texture/TextureImage.java
@@ -55,7 +55,8 @@ import javax.vecmath.*;
import org.jdesktop.j3d.examples.Resources;
public class TextureImage extends Applet {
-
+
+ private static final String defaultFileName = "resources/images/stone.jpg";
private java.net.URL texImage = null;
private SimpleUniverse u = null;
@@ -118,9 +119,9 @@ public class TextureImage extends Applet {
public void init() {
if (texImage == null) {
// the path to the image for an applet
- texImage = Resources.getResource("resources/images/stone.jpg");
+ texImage = Resources.getResource(defaultFileName);
if (texImage == null) {
- System.err.println("resources/images/stone.jpg not found");
+ System.err.println(defaultFileName + " not found");
System.exit(1);
}
}
@@ -161,9 +162,9 @@ public class TextureImage extends Applet {
}
} else {
// the path to the image for an application
- url = Resources.getResource("resources/images/stone.jpg");
+ url = Resources.getResource(defaultFileName);
if (url == null) {
- System.err.println("resources/images/stone.jpg not found");
+ System.err.println(defaultFileName + " not found");
System.exit(1);
}
}
diff --git a/src/classes/org/jdesktop/j3d/examples/texture/TextureImageNPOT.java b/src/classes/org/jdesktop/j3d/examples/texture/TextureImageNPOT.java
new file mode 100644
index 0000000..3976f0b
--- /dev/null
+++ b/src/classes/org/jdesktop/j3d/examples/texture/TextureImageNPOT.java
@@ -0,0 +1,222 @@
+/*
+ * $RCSfile$
+ *
+ * Copyright (c) 2006 Sun Microsystems, Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * - Redistribution of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ *
+ * - Redistribution in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in
+ * the documentation and/or other materials provided with the
+ * distribution.
+ *
+ * Neither the name of Sun Microsystems, Inc. or the names of
+ * contributors may be used to endorse or promote products derived
+ * from this software without specific prior written permission.
+ *
+ * This software is provided "AS IS," without a warranty of any
+ * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
+ * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
+ * EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL
+ * NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF
+ * USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS
+ * DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR
+ * ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL,
+ * CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND
+ * REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR
+ * INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGES.
+ *
+ * You acknowledge that this software is not designed, licensed or
+ * intended for use in the design, construction, operation or
+ * maintenance of any nuclear facility.
+ *
+ * $Revision$
+ * $Date$
+ * $State$
+ */
+
+package org.jdesktop.j3d.examples.texture;
+
+import java.applet.Applet;
+import java.awt.*;
+import com.sun.j3d.utils.applet.MainFrame;
+import com.sun.j3d.utils.universe.*;
+import com.sun.j3d.utils.image.TextureLoader;
+import com.sun.j3d.utils.geometry.Box;
+import javax.media.j3d.*;
+import javax.vecmath.*;
+import java.util.Map;
+import org.jdesktop.j3d.examples.Resources;
+
+public class TextureImageNPOT extends Applet {
+
+ private static final String defaultFileName = "resources/images/Java3d.jpg";
+ private java.net.URL texImage = null;
+
+ private SimpleUniverse u = null;
+ private boolean allowNonPowerOfTwo = true;
+ private boolean mipmap = true;
+
+ public BranchGroup createSceneGraph() {
+ // Create the root of the branch graph
+ BranchGroup objRoot = new BranchGroup();
+
+ // Create the transform group node and initialize it to the
+ // identity. Enable the TRANSFORM_WRITE capability so that
+ // our behavior code can modify it at runtime. Add it to the
+ // root of the subgraph.
+ TransformGroup objTrans = new TransformGroup();
+ objTrans.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE);
+ objRoot.addChild(objTrans);
+
+ // Create the scaling transform group node and initialize it to the
+ // identity. Enable the TRANSFORM_WRITE capability so that
+ // our behavior code can modify it at runtime. Add it to the
+ // objTrans group
+ TransformGroup objScale = new TransformGroup();
+ objScale.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE);
+ objTrans.addChild(objScale);
+
+ // Create appearance object for textured cube
+ Appearance app = new Appearance();
+ int flags = 0;
+ if (allowNonPowerOfTwo) {
+ flags |= TextureLoader.ALLOW_NON_POWER_OF_TWO;
+ }
+ if (mipmap) {
+ flags |= TextureLoader.GENERATE_MIPMAP;
+ }
+ Texture tex = new TextureLoader(texImage, flags, this).getTexture();
+ tex.setMagFilter(Texture.BASE_LEVEL_LINEAR);
+ if (mipmap) {
+ tex.setMinFilter(Texture.MULTI_LEVEL_LINEAR);
+ } else {
+ tex.setMinFilter(Texture.BASE_LEVEL_LINEAR);
+ }
+ app.setTexture(tex);
+ TextureAttributes texAttr = new TextureAttributes();
+ texAttr.setTextureMode(TextureAttributes.MODULATE);
+ app.setTextureAttributes(texAttr);
+
+ // Create textured cube and add it to the scene graph.
+ Box textureCube = new Box(0.4f, 0.4f, 0.4f,
+ Box.GENERATE_TEXTURE_COORDS, app);
+ objScale.addChild(textureCube);
+
+ // Create a new Behavior object that will perform the desired
+ // operation on the specified transform object and add it into
+ // the scene graph.
+ Transform3D yAxis = new Transform3D();
+ Alpha rotationAlpha = new Alpha(-1, Alpha.INCREASING_ENABLE,
+ 0, 0,
+ 50000, 0, 0,
+ 0, 0, 0);
+
+ RotationInterpolator rotator =
+ new RotationInterpolator(rotationAlpha, objTrans, yAxis,
+ 0.0f, (float) Math.PI*2.0f);
+ BoundingSphere bounds =
+ new BoundingSphere(new Point3d(0.0,0.0,0.0), 100.0);
+ rotator.setSchedulingBounds(bounds);
+ objTrans.addChild(rotator);
+
+ // Create a new Behavior object that will perform the desired
+ // operation on the specified transform object and add it into
+ // the scene graph.
+ Alpha scaleAlpha = new Alpha(-1,
+ Alpha.INCREASING_ENABLE | Alpha.DECREASING_ENABLE,
+ 0, 0,
+ 8000, 0, 0,
+ 8000, 0, 0);
+
+ ScaleInterpolator scaler =
+ new ScaleInterpolator(scaleAlpha, objScale, yAxis,
+ 0.01f, 1.5f);
+ scaler.setSchedulingBounds(bounds);
+ objScale.addChild(scaler);
+
+ // Have Java 3D perform optimizations on this scene graph.
+ objRoot.compile();
+
+ return objRoot;
+ }
+
+ public TextureImageNPOT() {
+ }
+
+ public TextureImageNPOT(java.net.URL url) {
+ texImage = url;
+ }
+
+ public void init() {
+ if (texImage == null) {
+ // the path to the image for an applet
+ texImage = Resources.getResource(defaultFileName);
+ if (texImage == null) {
+ System.err.println(defaultFileName + " not found");
+ System.exit(1);
+ }
+ }
+ setLayout(new BorderLayout());
+ GraphicsConfiguration config =
+ SimpleUniverse.getPreferredConfiguration();
+
+ Canvas3D c = new Canvas3D(config);
+
+ Map map = c.queryProperties();
+ Boolean value = (Boolean) map.get("textureNonPowerOfTwoAvailable");
+ if (value != null) {
+ System.out.println("textureNonPowerOfTwoAvailable property = " + value);
+ } else {
+ System.out.println("textureNonPowerOfTwoAvailable property not found");
+ }
+
+ add("Center", c);
+
+ // Create a simple scene and attach it to the virtual universe
+ BranchGroup scene = createSceneGraph();
+ u = new SimpleUniverse(c);
+
+ // This will move the ViewPlatform back a bit so the
+ // objects in the scene can be viewed.
+ u.getViewingPlatform().setNominalViewingTransform();
+
+ u.addBranchGraph(scene);
+ }
+
+ public void destroy() {
+ u.cleanup();
+ }
+
+ //
+ // The following allows TextureImageNPOT to be run as an application
+ // as well as an applet
+ //
+ public static void main(String[] args) {
+ java.net.URL url = null;
+ if (args.length > 0) {
+ try {
+ url = new java.net.URL("file:" + args[0]);
+ } catch (java.net.MalformedURLException ex) {
+ System.out.println(ex.getMessage());
+ System.exit(1);
+ }
+ } else {
+ // the path to the image for an application
+ url = Resources.getResource(defaultFileName);
+ if (url == null) {
+ System.err.println(defaultFileName + " not found");
+ System.exit(1);
+ }
+ }
+ new MainFrame(new TextureImageNPOT(url), 512, 512);
+ }
+
+}
diff --git a/src/classes/org/jdesktop/j3d/examples/geometry_compression/ObjectFileCompressor.java b/src/classes/org/jdesktop/j3d/examples/geometry_compression/ObjectFileCompressor.java
index 57267eb..2155581 100644
--- a/src/classes/org/jdesktop/j3d/examples/geometry_compression/ObjectFileCompressor.java
+++ b/src/classes/org/jdesktop/j3d/examples/geometry_compression/ObjectFileCompressor.java
@@ -44,15 +44,17 @@
package org.jdesktop.j3d.examples.geometry_compression;
-import com.sun.j3d.utils.compression.* ;
-import com.sun.j3d.loaders.objectfile.ObjectFile ;
-import com.sun.j3d.loaders.ParsingErrorException ;
-import com.sun.j3d.loaders.IncorrectFormatException ;
-import com.sun.j3d.loaders.Scene ;
-import javax.media.j3d.* ;
-import java.util.* ;
-import java.net.* ;
-import java.io.* ;
+import com.sun.j3d.loaders.IncorrectFormatException;
+import com.sun.j3d.loaders.ParsingErrorException;
+import com.sun.j3d.loaders.Scene;
+import com.sun.j3d.loaders.objectfile.ObjectFile;
+import com.sun.j3d.utils.geometry.compression.*;
+import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.io.Reader;
+import java.net.URL;
+import java.util.Hashtable;
+import javax.media.j3d.Shape3D;
/**
* This extension of ObjectFile provides the methods setQuantization() and
@@ -104,12 +106,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
* Compress the specified .obj file into a CompressedGeometry node
* component.
* @param objFileName String object representing the path to a .obj file
* @return a CompressedGeometry node component
*/
- public CompressedGeometry compress(String objFileName) {
+ public CompressedGeometryData compress(String objFileName) {
return compressScene(getScene(objFileName)) ;
}
@@ -126,12 +128,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
* Compress the specified .obj file into a CompressedGeometry node
* component.
* @param reader an open .obj file
* @return a CompressedGeometry node component
*/
- public CompressedGeometry compress(Reader reader) {
+ public CompressedGeometryData compress(Reader reader) {
return compressScene(getScene(reader)) ;
}
@@ -148,12 +150,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
* Compress the specified .obj file into a CompressedGeometry node
* component.
* @param url Uniform Resource Locator for the .obj file
* @return a CompressedGeometry node component
*/
- public CompressedGeometry compress(URL url) {
+ public CompressedGeometryData compress(URL url) {
return compressScene(getScene(url)) ;
}
@@ -169,7 +171,7 @@ public class ObjectFileCompressor extends ObjectFile {
compressScene(getScene(url), file) ;
}
- private CompressedGeometry compressScene(Scene scene) {
+ private CompressedGeometryData compressScene(Scene scene) {
return compressor.compress(getStream(scene)) ;
}
@@ -104,12 +106,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
- * Compress the specified .obj file into a CompressedGeometry node
+ * Compress the specified .obj file into a CompressedGeometryData node
* component.
* @param objFileName String object representing the path to a .obj file
@@ -104,12 +106,12 @@ public class ObjectFileCompressor extends ObjectFile {
* component.
* @param objFileName String object representing the path to a .obj file
- * @return a CompressedGeometry node component
+ * @return a CompressedGeometryData node component
*/
@@ -126,12 +128,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
- * Compress the specified .obj file into a CompressedGeometry node
+ * Compress the specified .obj file into a CompressedGeometryData node
* component.
* @param reader an open .obj file
@@ -126,12 +128,12 @@ public class ObjectFileCompressor extends ObjectFile {
* component.
* @param reader an open .obj file
- * @return a CompressedGeometry node component
+ * @return a CompressedGeometryData node component
*/
@@ -148,12 +150,12 @@ public class ObjectFileCompressor extends ObjectFile {
}
/**
- * Compress the specified .obj file into a CompressedGeometry node
+ * Compress the specified .obj file into a CompressedGeometryData node
* component.
* @param url Uniform Resource Locator for the .obj file
@@ -148,12 +150,12 @@ public class ObjectFileCompressor extends ObjectFile {
* component.
* @param url Uniform Resource Locator for the .obj file
- * @return a CompressedGeometry node component
+ * @return a CompressedGeometryData node component
*/